var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AuthorizeSecurityGroupIngressCommand, CreateSecurityGroupCommand, DescribeSecurityGroupRulesCommand, waitUntilSecurityGroupExists, } from '@aws-sdk/client-ec2';
import { COMMON_WAITER_CONFIG } from '../common/waiter-config.js';
import { handleWaiterError } from '../common/waiter-error.js';
import { toTagSpecification } from '../tags/utils/to-tag-specification.js';
import { ec2Client } from './ec2-client.js';
import { upsertTags } from './upsert-tags.js';
export function createSecurityGroup({ name, description, vpcId, ingressRules, tags, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const { GroupId } = yield ec2Client.send(new CreateSecurityGroupCommand({
            GroupName: name,
            Description: description,
            VpcId: vpcId,
            TagSpecifications: [
                toTagSpecification('security-group', [
                    ...tags,
                    { key: 'Name', value: name },
                ]),
            ],
        }));
        if (GroupId === undefined) {
            throw new Error(`Invalid response from AWS.`);
        }
        yield handleWaiterError(() => __awaiter(this, void 0, void 0, function* () {
            return yield waitUntilSecurityGroupExists(Object.assign(Object.assign({}, COMMON_WAITER_CONFIG), { client: ec2Client.client }), { GroupIds: [GroupId] });
        }));
        const defaultSecurityGroupRuleIds = yield getSecurityGroupRuleIds(GroupId);
        yield upsertTags({
            resourceIds: defaultSecurityGroupRuleIds,
            tags,
        });
        if (ingressRules.length > 0) {
            yield ec2Client.send(new AuthorizeSecurityGroupIngressCommand({
                GroupId,
                IpPermissions: ingressRules.map(rule => toIpPermission(rule)),
                TagSpecifications: tags.length > 0
                    ? [toTagSpecification('security-group-rule', tags)]
                    : undefined,
            }));
        }
        return {
            id: GroupId,
            name,
            description,
            vpcId,
            ingressRules,
        };
    });
}
function getSecurityGroupRuleIds(groupId) {
    return __awaiter(this, void 0, void 0, function* () {
        const { SecurityGroupRules } = yield ec2Client.send(new DescribeSecurityGroupRulesCommand({
            Filters: [
                {
                    Name: 'group-id',
                    Values: [groupId],
                },
            ],
        }));
        if (SecurityGroupRules === undefined ||
            SecurityGroupRules.some(rule => rule.SecurityGroupRuleId === undefined)) {
            throw new Error(`Invalid response from AWS.`);
        }
        return SecurityGroupRules.map(rule => rule.SecurityGroupRuleId);
    });
}
function toIpPermission(rule) {
    var _a, _b;
    const IpRanges = rule.sources
        // eslint-disable-next-line unicorn/no-array-callback-reference -- breaks type guard
        .filter(isIpRangeSource)
        .map(source => ({ CidrIp: source.cidrIp }));
    const UserIdGroupPairs = rule.sources
        // eslint-disable-next-line unicorn/no-array-callback-reference -- breaks type guard
        .filter(isSecurityGroupSource)
        .map(source => ({ GroupId: source.securityGroupId }));
    const sources = {
        IpRanges: IpRanges.length > 0 ? IpRanges : undefined,
        UserIdGroupPairs: UserIdGroupPairs.length > 0 ? UserIdGroupPairs : undefined,
    };
    return Object.assign({ FromPort: (_a = rule.ports) === null || _a === void 0 ? void 0 : _a.from, ToPort: (_b = rule.ports) === null || _b === void 0 ? void 0 : _b.to, IpProtocol: rule.ipProtocol }, sources);
}
function isIpRangeSource(source) {
    return 'cidrIp' in source;
}
function isSecurityGroupSource(source) {
    return 'securityGroupId' in source;
}
//# sourceMappingURL=create-security-group.js.map