var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { InstanceStateName } from '@aws-sdk/client-ec2';
import { getEc2Instances } from '../aws/ec2/get-ec2-instances.js';
import { ManagedResourceTypes } from '../common/resource-type.js';
import { ResourceDamagedError, UnexpectedStateError, } from '../common/runtime-errors.js';
import { BASTION_INSTANCE_ID_TAG_NAME, BASTION_INSTANCE_SECURITY_GROUP_NAME_PREFIX, BASTION_INSTANCE_UPDATING_TAG_NAME, } from './bastion.js';
const BASTION_INSTANCE_UPDATING_TIMEOUT = 1000 * 60 * 10;
export function getBastion({ bastionId, vpcId, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const [instance] = yield getEc2Instances({
            tags: [
                {
                    key: BASTION_INSTANCE_ID_TAG_NAME,
                    value: bastionId !== null && bastionId !== void 0 ? bastionId : '*',
                },
            ],
            states: [
                InstanceStateName.pending,
                InstanceStateName.running,
                InstanceStateName.stopping,
                InstanceStateName.stopped,
            ],
            vpcId,
        });
        if (instance === undefined) {
            return;
        }
        const id = getBastionId(instance);
        const state = getBastionInstanceState(instance);
        const securityGroup = getBastionInstanceSecurityGroup(instance);
        return {
            id,
            instance,
            state,
            securityGroupId: securityGroup.id,
            securityGroupName: securityGroup.name,
        };
    });
}
function getBastionId(instance) {
    const id = instance.tags[BASTION_INSTANCE_ID_TAG_NAME];
    if (id === undefined) {
        throw new UnexpectedStateError(new ResourceDamagedError(ManagedResourceTypes.BASTION_INSTANCE, instance.id, `"${BASTION_INSTANCE_ID_TAG_NAME}" tag is missing`));
    }
    return id;
}
function getBastionInstanceState(instance) {
    const now = new Date();
    const updatingTime = parseTimeTag(instance, BASTION_INSTANCE_UPDATING_TAG_NAME);
    if (
    // Instance is running
    instance.state === InstanceStateName.running &&
        // It started updating
        updatingTime !== undefined &&
        // The update started recently
        now.getTime() - updatingTime.getTime() < BASTION_INSTANCE_UPDATING_TIMEOUT) {
        return 'updating';
    }
    return instance.state;
}
function getBastionInstanceSecurityGroup(instance) {
    const securityGroup = instance.securityGroups.find(group => group.name.startsWith(BASTION_INSTANCE_SECURITY_GROUP_NAME_PREFIX));
    if (!securityGroup) {
        throw new UnexpectedStateError(new ResourceDamagedError(ManagedResourceTypes.BASTION_INSTANCE, instance.id, `No bastion security group associated with the instance`));
    }
    return securityGroup;
}
function parseTimeTag(instance, tagName) {
    const vagValue = instance.tags[tagName];
    if (vagValue === undefined) {
        return;
    }
    try {
        return new Date(vagValue);
    }
    catch (_a) {
        throw new UnexpectedStateError(new ResourceDamagedError(ManagedResourceTypes.BASTION_INSTANCE, instance.id, `"${tagName}" tag has invalid value`));
    }
}
//# sourceMappingURL=get-bastion.js.map