var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { parseMemcachedCacheClusterResponse } from '#src/aws/elasticache/parse-elasticache-memcached-response.js';
import { getRawMemcachedClusters } from '#src/aws/elasticache/get-elasticache-memcached-clusters.js';
import { AwsDependencyViolationError } from '../aws/common/aws-errors.js';
import { deleteSecurityGroup } from '../aws/ec2/delete-security-group.js';
import { getDbClusters } from '../aws/rds/get-db-clusters.js';
import { getDbInstances } from '../aws/rds/get-db-instances.js';
import { modifyDBCluster } from '../aws/rds/modify-db-cluster.js';
import { modifyDbInstance } from '../aws/rds/modify-db-instance.js';
import { retry } from '../common/retry.js';
import { getRawReplicationGroups } from '../aws/elasticache/get-elasticache-replication-groups.js';
import { getRawCacheClusters } from '../aws/elasticache/get-elasticache-cache-clusters.js';
import { modifyElasticacheMemcachedCluster, modifyElasticacheReplicationGroup, } from '../aws/elasticache/modify-elasticache-clusters.js';
export const accessSecurityGroupReferencesCleaner = (groupIds) => __awaiter(void 0, void 0, void 0, function* () {
    const groupIdSet = new Set(groupIds);
    yield cleanupDbInstanceReferences(groupIdSet);
    yield cleanupDbClusterReferences(groupIdSet);
    yield cleanupElasticacheSecurityGroups(groupIdSet);
});
export const securityGroupCleaner = (groupId) => __awaiter(void 0, void 0, void 0, function* () {
    yield retry(() => __awaiter(void 0, void 0, void 0, function* () { return yield deleteSecurityGroup({ groupId }); }), {
        delay: 3000,
        maxRetries: 15,
        shouldRetry: error => error instanceof AwsDependencyViolationError,
    });
});
function cleanupDbInstanceReferences(securityGroupIds) {
    return __awaiter(this, void 0, void 0, function* () {
        const dbInstances = yield getDbInstances();
        const dbInstancesWithReferences = dbInstances.filter(instance => arrayContains(instance.securityGroupIds, securityGroupIds));
        if (dbInstancesWithReferences.length === 0) {
            return;
        }
        for (const dbInstance of dbInstancesWithReferences) {
            yield modifyDbInstance({
                identifier: dbInstance.identifier,
                securityGroupIds: filterOut(dbInstance.securityGroupIds, securityGroupIds),
            });
        }
    });
}
function cleanupDbClusterReferences(securityGroupsIds) {
    return __awaiter(this, void 0, void 0, function* () {
        const dbClusters = yield getDbClusters();
        const dbClustersWithReferences = dbClusters.filter(cluster => arrayContains(cluster.securityGroupIds, securityGroupsIds));
        if (dbClustersWithReferences.length === 0) {
            return;
        }
        for (const dbCluster of dbClustersWithReferences) {
            yield modifyDBCluster({
                identifier: dbCluster.identifier,
                securityGroupIds: filterOut(dbCluster.securityGroupIds, securityGroupsIds),
            });
        }
    });
}
export function cleanupElasticacheSecurityGroups(groupIds) {
    return __awaiter(this, void 0, void 0, function* () {
        const cacheClusters = yield getRawCacheClusters();
        const replicationGroups = yield getRawReplicationGroups();
        const memcachedClusters = yield getRawMemcachedClusters();
        for (const replicationGroup of replicationGroups) {
            yield cleanReplicationGroup(replicationGroup, cacheClusters, groupIds);
        }
        for (const memcachedCluster of memcachedClusters) {
            yield cleanElasticacheMemcachedCluster(memcachedCluster, groupIds);
        }
    });
}
function cleanReplicationGroup(replicationGroup, cacheClusters, groupIds) {
    return __awaiter(this, void 0, void 0, function* () {
        if (replicationGroup.NodeGroups === undefined ||
            replicationGroup.NodeGroups[0] === undefined ||
            replicationGroup.NodeGroups[0].NodeGroupMembers === undefined ||
            replicationGroup.NodeGroups[0].NodeGroupMembers[0] === undefined)
            return;
        const exampleCacheCluster = replicationGroup.NodeGroups[0].NodeGroupMembers[0].CacheClusterId;
        const cacheSecurityGroups = cacheClusters.find(cache => cache.CacheClusterId === exampleCacheCluster);
        if (cacheSecurityGroups === undefined ||
            cacheSecurityGroups.SecurityGroups === undefined)
            return;
        const cacheSecurityGroupsIds = [
            ...cacheSecurityGroups.SecurityGroups.flatMap(group => { var _a; return (_a = group.SecurityGroupId) !== null && _a !== void 0 ? _a : ' '; }).filter(id => id !== ' ' && !groupIds.has(id)),
        ];
        if (cacheSecurityGroupsIds.length !== cacheSecurityGroups.SecurityGroups.length) {
            yield modifyElasticacheReplicationGroup({
                identifier: replicationGroup.ReplicationGroupId,
                securityGroupIds: cacheSecurityGroupsIds,
                cachePreviousSecurityGroups: cacheSecurityGroups.SecurityGroups,
            });
        }
    });
}
function cleanElasticacheMemcachedCluster(memcachedCluster, groupIds) {
    return __awaiter(this, void 0, void 0, function* () {
        if (memcachedCluster === undefined ||
            memcachedCluster.SecurityGroups === undefined)
            return;
        const parsed = parseMemcachedCacheClusterResponse(memcachedCluster);
        const cacheSecurityGroupsIds = filterOut(parsed.securityGroups, groupIds);
        if (cacheSecurityGroupsIds.length !== memcachedCluster.SecurityGroups.length) {
            yield modifyElasticacheMemcachedCluster({
                identifier: memcachedCluster.CacheClusterId,
                securityGroupIds: cacheSecurityGroupsIds,
                cachePreviousSecurityGroups: memcachedCluster.SecurityGroups,
            });
        }
    });
}
function arrayContains(arr, set) {
    return arr.some(el => set.has(el));
}
function filterOut(arr, set) {
    return arr.filter(el => !set.has(el));
}
//# sourceMappingURL=security-group-cleaner.js.map