var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AwsSsmInstanceNotConnectedError } from '#src/aws/ssm/ssm-errors.js';
import { EarlyExitError } from '#src/cli/error/early-exit-error.js';
import { cli } from '#src/common/cli.js';
import { fmt } from '#src/common/fmt.js';
import { SessionManagerPluginExitError, SessionManagerPluginNonInstalledError, SessionManagerPluginPortInUseError, SessionManagerPluginTimeoutError, } from '#src/session/session-errors.js';
import { startPortForwardingSession } from '#src/session/start-port-forwarding-session.js';
import { retry } from '#src/common/retry.js';
import { detailProvider, getErrorDetail, } from '../../error/get-error-detail.js';
import { OperationError } from '../../error/operation-error.js';
export function startPortForwarding({ target, bastionInstanceId, localPort, }) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            cli.progressStart('Starting port forwarding session');
            yield startPortForwardingSessionWithRetries(target, bastionInstanceId, localPort, {
                onSessionError: handleSessionError,
                onSessionEnded: handleSessionEnded,
                onMarkingError: handleMarkingError,
            });
            cli.progressStop();
            cli.info(`Port ${fmt.value(String(localPort))} is open for your connections`, '🚀');
        }
        catch (error) {
            cli.progressFailure();
            handleSessionStartError(error, localPort);
        }
    });
}
function startPortForwardingSessionWithRetries(target, bastionInstanceId, localPort, hooks) {
    return __awaiter(this, void 0, void 0, function* () {
        yield retry(() => __awaiter(this, void 0, void 0, function* () {
            return yield startPortForwardingSession({
                target,
                bastionInstanceId,
                localPort,
                hooks,
            });
        }), {
            delay: 1000,
            maxRetries: 10,
            shouldRetry: error => error instanceof SessionManagerPluginTimeoutError,
        });
    });
}
function handleSessionEnded(exitDescription) {
    throw new EarlyExitError('Port forwarding session ended. Please, check your AWS Session Manager time out settings', formatExitDescription(exitDescription));
}
function handleSessionError(error) {
    throw OperationError.fromError({
        operationName: 'Running port forwarding session',
        error,
        detailProviders: [getSessionManagerExitDetailProvider()],
    });
}
function handleMarkingError(error) {
    cli.warn(`Can't mark bastion usage.  ${getErrorDetail(error)}. This might lead to session interruption.`);
}
function handleSessionStartError(error, localPort) {
    throw OperationError.fromError({
        operationName: 'Starting port forwarding session',
        error,
        detailProviders: [
            detailProvider(AwsSsmInstanceNotConnectedError, () => `Bastion instance is not connected to SSM. The instance might have been created in a private VPC subnet during ${fmt.code('basti init')}`),
            detailProvider(SessionManagerPluginNonInstalledError, () => 'session-manager-plugin was not installed automatically with Basti. You can install it manually following the official manual: https://docs.aws.amazon.com/systems-manager/latest/userguide/session-manager-working-with-install-plugin.html'),
            detailProvider(SessionManagerPluginPortInUseError, () => `Local port ${fmt.value(String(localPort))} is already in use`),
            getSessionManagerExitDetailProvider(),
            detailProvider(SessionManagerPluginTimeoutError, error => formatTimeoutError(error.output)),
        ],
    });
}
function getSessionManagerExitDetailProvider() {
    return detailProvider(SessionManagerPluginExitError, error => {
        return formatExitDescription(error.exitDescription);
    });
}
function formatExitDescription(exitDescription) {
    const output = formatOutput(exitDescription);
    if (typeof exitDescription.reason === 'number') {
        return `session-manager-plugin exited with code ${exitDescription.reason}${output}`;
    }
    return `session-manager-plugin exited due to ${exitDescription.reason} signal${output}`;
}
function formatTimeoutError(processOutput) {
    const output = formatOutput(processOutput);
    return `session-manager-plugin did not start the port forwarding session${output}`;
}
function formatOutput(processOutput) {
    const output = processOutput.output.length > 0
        ? `\n\nOutput:\n${processOutput.output.trim()}`
        : '';
    const errorOutput = processOutput.errorOutput.length > 0
        ? `\n\nError output:\n${processOutput.errorOutput.trim()}`
        : '';
    return `${output}${errorOutput}`;
}
//# sourceMappingURL=start-port-forwarding.js.map