var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import inquirer from 'inquirer';
import ora from 'ora';
import { isDebugMode } from './debug.js';
import { fmt } from './fmt.js';
import { toArray } from './data-structures.js';
export class Cli {
    constructor({ indent, spinner, context, onContextChange, }) {
        this.indent = indent !== null && indent !== void 0 ? indent : 0;
        this.spinner = spinner !== null && spinner !== void 0 ? spinner : ora();
        this.context = context !== null && context !== void 0 ? context : 'none';
        this.onContextChange = onContextChange;
    }
    static create(input = {}) {
        return new Cli(input);
    }
    createSubInstance(input = {}) {
        const subSpinner = input.indent !== undefined ? ora({ indent: input.indent }) : this.spinner;
        return new Cli(Object.assign(Object.assign({}, input), { spinner: subSpinner, context: this.context, onContextChange: context => this.changeContext(context) }));
    }
    exitContext() {
        this.changeContext('none');
    }
    out(text) {
        this.exitContext();
        this.print(text);
    }
    info(text, symbol = 'ℹ️') {
        this.enterContext('info');
        this.print(`${symbol} ${text}`);
    }
    success(text) {
        this.enterContext('success');
        this.print(`${fmt.green('✔')} ${text}`);
    }
    warn(text) {
        this.enterContext('warn');
        this.print(fmt.yellow(`⚠ ${text}`));
    }
    error(text) {
        this.enterContext('error');
        this.print(fmt.red(`❌ ${text}`));
    }
    debug(text) {
        if (!isDebugMode()) {
            return;
        }
        this.enterContext('debug');
        this.print(fmt.gray(text));
    }
    progressStart(text) {
        this.changeContext('progress');
        this.spinner.start(text);
    }
    progressStop() {
        if (this.context !== 'progress') {
            return;
        }
        this.exitContext();
        this.spinner.stop();
    }
    progressSuccess(text, symbol) {
        if (this.context !== 'progress') {
            return;
        }
        this.exitContext();
        symbol !== undefined
            ? this.spinner.stopAndPersist({ symbol })
            : this.spinner.succeed(text);
    }
    progressFailure(text) {
        if (this.context !== 'progress') {
            return;
        }
        this.exitContext();
        this.spinner.fail(text);
    }
    progressWarn(input) {
        var _a;
        if (this.context !== 'progress') {
            return;
        }
        this.exitContext();
        const currentText = this.spinner.text;
        const text = input && `${(_a = input.text) !== null && _a !== void 0 ? _a : currentText} - ${fmt.yellow(input.warnText)}`;
        this.spinner.stopAndPersist({
            symbol: fmt.yellow('⚠'),
            text,
        });
    }
    prompt(questions, initialAnswers) {
        const unifiedQuestions = toArray(questions).map(question => {
            const { message, prefix } = question;
            return Object.assign(Object.assign({}, question), { message: typeof message === 'function'
                    ? (answers) => __awaiter(this, void 0, void 0, function* () { return fmt.reset(yield message(answers)); })
                    : typeof message === 'string'
                        ? fmt.reset(message)
                        : message, prefix: this.indentText(prefix !== null && prefix !== void 0 ? prefix : fmt.green('?')) });
        });
        this.changeContext('none');
        return inquirer.prompt(unifiedQuestions, initialAnswers);
    }
    print(text) {
        this.progressStop();
        console.log(this.indentText(text));
    }
    enterContext(context) {
        if (this.context !== context) {
            this.out('\n');
        }
        this.changeContext(context);
    }
    indentText(text) {
        return (this.getIndentStr() +
            text.replace(Cli.NEW_LINE_REGEXP, newLine => newLine + this.getIndentStr()));
    }
    changeContext(context) {
        var _a;
        this.context = context;
        (_a = this.onContextChange) === null || _a === void 0 ? void 0 : _a.call(this, context);
    }
    getIndentStr() {
        return ' '.repeat(this.indent);
    }
}
Cli.NEW_LINE_REGEXP = /(\r\n|\r|\n)/g;
export const cli = Cli.create();
//# sourceMappingURL=cli.js.map